==> LWP-Simple-REST-0.06.tar.gz: LWP-Simple-REST-0.06/README.md <==
 
                             LWP-Simple-REST
           --------------------------------------------------
           
The LWP-Simple-REST module is a requester of an web application. When you
need to send a request intoa a script, it makes easy because you don't need
create a UserAgent and create the requester to make a request into a server.

PREREQUISITES

In order to install and use this package you will need Perl version
5.14.4 or better. Some modules within this package depend on other
packages that are distributed separately from Perl.  We recommend that
you have the following packages installed before you install

LWP::UserAgent
HTTP::Request
Try::Tiny
JSON

DOCUMENTATION

See the lib/LWP/Simple/REST.pm file for an overview of the library. See the
Changes file for recent changes.

POD style documentation is included in all modules and scripts.  These
are normally converted to manual pages and installed as part of the
"make install" process.  You should also be able to use the 'perldoc'
utility to extract and read documentation from the module files
directly.


SUPPORT

Bug reports and suggestions for improvements can be sent to the
<italo.goncales@gmail.com> or <cartas@frederico.me>.

AVAILABILITY

If you want to hack on the source it might be a good idea to grab the
latest version with git using the command:

     git clone git@github.com:ItaloGoncales/LWP-Simple-REST.git lwp-simple-rest

You can also browse the git repository at:

     https://github.com/ItaloGoncales/LWP-Simple-REST

Enjoy!

==> LWP-Simple-REST-0.20.tar.gz: LWP-Simple-REST-0.20/README.md <==
[![Build Status](https://travis-ci.org/ItaloGoncales/LWP-Simple-REST.svg?branch=master)](https://travis-ci.org/ItaloGoncales/LWP-Simple-REST)
[![endorse](https://api.coderwall.com/Goncales/endorsecount.png)](https://coderwall.com/Goncales)
 
                             LWP-Simple-REST
           --------------------------------------------------
           
The LWP-Simple-REST module is a requester of an web application. When you
need to send a request intoa a script, it makes easy because you don't need
create a UserAgent and create the requester to make a request into a server.

PREREQUISITES

In order to install and use this package you will need Perl version
5.14.4 or better. Some modules within this package depend on other
packages that are distributed separately from Perl.  We recommend that
you have the following packages installed before you install

LWP::UserAgent
HTTP::Request
Try::Tiny
JSON

DOCUMENTATION

See the lib/LWP/Simple/REST.pm file for an overview of the library. See the
Changes file for recent changes.

POD style documentation is included in all modules and scripts.  These
are normally converted to manual pages and installed as part of the
"make install" process.  You should also be able to use the 'perldoc'
utility to extract and read documentation from the module files
directly.


SUPPORT

Bug reports and suggestions for improvements can be sent to the
<italo.goncales@gmail.com> or <recsky@cpan.org>.

AVAILABILITY

If you want to hack on the source it might be a good idea to grab the
latest version with git using the command:

     git clone git@github.com:ItaloGoncales/LWP-Simple-REST.git lwp-simple-rest

You can also browse the git repository at:

     https://github.com/ItaloGoncales/LWP-Simple-REST

Enjoy!
